Client

Trait Client 

pub trait Client<T: GattTypes> {
    // Required methods
    fn peer_id(&self) -> PeerId;
    fn find_service(&self, uuid: Uuid) -> T::FindServicesFut;
}
GATT Client connected to a particular peer. Holding a struct that implements this should attempt to maintain a LE connection to the peer.

Required Methods

fn peer_id(&self) -> PeerId

The ID of the peer this is connected to.

fn find_service(&self, uuid: Uuid) -> T::FindServicesFut

Find services by UUID on the peer. This may cause as much as a full discovery of all services on the peer if the stack deems it appropriate. Service information should be up to date at the time returned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors