pub trait GattTypes: Sized {
Show 13 associated items
type Central: Central<Self>;
type ScanResultStream: Stream<Item = Result<ScanResult>> + 'static;
type Client: Client<Self>;
type ConnectFuture: Future<Output = Result<Self::Client>>;
type PeerServiceHandle: PeerServiceHandle<Self>;
type FindServicesFut: Future<Output = Result<Vec<Self::PeerServiceHandle>>> + 'static;
type PeerService: PeerService<Self>;
type ServiceConnectFut: Future<Output = Result<Self::PeerService>>;
type CharacteristicDiscoveryFut: Future<Output = Result<Vec<Characteristic>>>;
type NotificationStream: Stream<Item = Result<CharacteristicNotification>> + 'static;
type ReadFut<'a>: Future<Output = Result<(usize, bool)>> + 'a;
type WriteFut<'a>: Future<Output = Result<()>> + 'a;
type PeriodicAdvertising: PeriodicAdvertising;
}Expand description
Implementors implement traits with respect to GattTypes. Implementation crates provide an object which relates a constellation of types to each other, used to provide concrete types for library crates to paramaterize on.
Required Associated Types
type Central: Central<Self>
type ScanResultStream: Stream<Item = Result<ScanResult>> + 'static
type Client: Client<Self>
type ConnectFuture: Future<Output = Result<Self::Client>>
type PeerServiceHandle: PeerServiceHandle<Self>
type FindServicesFut: Future<Output = Result<Vec<Self::PeerServiceHandle>>> + 'static
type PeerService: PeerService<Self>
type ServiceConnectFut: Future<Output = Result<Self::PeerService>>
Sourcetype CharacteristicDiscoveryFut: Future<Output = Result<Vec<Characteristic>>>
type CharacteristicDiscoveryFut: Future<Output = Result<Vec<Characteristic>>>
Future returned by PeerService::discover_characteristics, delivering the set of characteristics discovered within a service
Sourcetype NotificationStream: Stream<Item = Result<CharacteristicNotification>> + 'static
type NotificationStream: Stream<Item = Result<CharacteristicNotification>> + 'static
A stream of notifications, delivering updates to a characteristic value
that has been subscribed to. See client::PeerService::subscribe
Sourcetype ReadFut<'a>: Future<Output = Result<(usize, bool)>> + 'a
type ReadFut<'a>: Future<Output = Result<(usize, bool)>> + 'a
Future resolving when a characteristic or descriptor has been read. Resolves to a number of bytes read along with a boolean indicating if the value was possibly truncated, or an Error if the value could not be read.
Sourcetype WriteFut<'a>: Future<Output = Result<()>> + 'a
type WriteFut<'a>: Future<Output = Result<()>> + 'a
Future resolving when a characteristic or descriptor has been written. Returns an error if the value could not be written.
Sourcetype PeriodicAdvertising: PeriodicAdvertising
type PeriodicAdvertising: PeriodicAdvertising
The implementation of periodic advertising for this GATT implementation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".